@@ -32,7 +32,7 @@ def update_assets_parts(data, date):
 
 
 @plugin.register(chain='pricing', requires=['assets'])
-def parts(**kwargs):
+def assets_parts(**kwargs):
     """Updates the devices from Ralph Assets."""
     date = kwargs['today']
     count = sum(update_assets_parts(data, date) for data in get_asset_parts())
